import * as storage from '@root/utils/storage';
import getData from '@root/utils/request';
import Taro from '@tarojs/taro';
import { isReqSuccess } from '@root/utils/tool';
import { firstCharToLowerCase } from '../utils/tool';

async function saveSafeArea(dispatch) {
  const res = await Taro.getSystemInfo();
  console.log('system info:', res);
  if (res) {
    dispatch({
      type: 'app/update',
      payload: {
        statusBarHeight: res.statusBarHeight,
        safeArea: res.safeArea || {},
      }
    })
  }
}

export function logout() {
  return async (dispatch) => {
    dispatch({
      type: 'app/logout',
    });
  }
}

export function initApp() {
  return async (dispatch, getState ) => {
    saveSafeArea(dispatch);
  }
}


export function login({ username, password }) {
  return async (dispatch, getState) => {
    const res = await getData('authentication/login', { UserName: username, Password: password }, true);
    if (!isReqSuccess(res)) {
      dispatch(logout());
      return res;
    }
    const userData = firstCharToLowerCase(res.data);

    // 角色判断
    // const { app: appStore } = getState();
    // if (appStore.appType && userData.userType !== appStore.appType) { // 登录角色权限不符合，退出登录
    //   hint('账号权限不足');
    //   dispatch(logout());
    //   return false;
    // }
    const payload = {
      accountId: userData.id,
      accountName: userData.cnName,
      customerId: userData.companyId,
      avatorUrl: userData.headImgUrl,
    };
    storage.set('accountId', payload.accountId);
    dispatch({
      type: 'app/login',
      payload,
    });

    return res;
  }
};
